/*
 * This file is a part of KEMET project (Library).
 * 
 * Copyright (C) 2008 MAUPIN Fabrice
 *
 * This library is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; 
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library; 
 * if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
package org.kemet.tests.basic;

import org.apache.log4j.Logger;
import org.junit.Test;
import org.kemet.impl.grammar.GrammarManager;
import org.kemet.tests.TestRoot;

/**
 * 
 * @author fabricemaupin
 * 
 * <p>
 * <b>Grammar Manager Tests.</b>
 * </p>
 * 
 * @since 0.1
 */
public class TestGrammarManager extends TestRoot {
	static Logger log = Logger.getLogger("org.kemet.tests");

	/**
	 * <p>
	 * <b>list of signs.</b>
	 * </p>
	 */
	private String[] signList;

	/**
	 * <p>
	 * <b>list of transliterated sequences.</b>
	 * </p>
	 */
	private String[] transliterationList;

	/**
	 * <p>
	 * <b>set the parameters before execute the tests.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	public void init() {
		// initialize the data tests...
		signList = new String[] { "G1_N29_G37", "M17_O34_I9_X1_G37",
				"G43_D58_N35_N8", "I9_N29_G1_Z8_Y1", "G17_S29_V28_I3",
				"O4_D21_G43_N5", "F32_V31_D21_Aa30", "S29_D58_V28_F18_A2",
				"W11_D21_V28_N2", "D46_G1_M17_Z7_Y5" };

		transliterationList = new String[] { "jqr", "jkn", "bnr", "psh.",
				"nt_r.t", "rd", "h.f3w", "ss^n", "s^mc", "d_d" };
	}

	/**
	 * <p>
	 * <b>test for initialisation of grammar manager.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	@Test
	public void testInitialization() {
		// verify that the grammar manager initialize well
		try {
			gm = new GrammarManager(selectedGrammar + "."
					+ grammarMainClassName, args);
			assertTrue(true);
		} catch (Exception e) {
			assertTrue(false);
		}

		// verify the class name
		try {
			new GrammarManager(selectedGrammar + "." + "bidon", args);
			assertTrue(false);
		} catch (Exception e) {
			assertTrue(true);
		}

		// verify if the class name = null
		try {
			new GrammarManager(null, args);
			assertTrue(false);
		} catch (Exception e) {
			assertTrue(true);
		}

		// file not found
		args.put("file1", "bidon");
		try {
			new GrammarManager(selectedGrammar + "." + grammarMainClassName,
					args);
			assertTrue(false);
		} catch (Exception e) {
			assertTrue(true);
		}

		// empty file
		args.put("file1", "hiero.xml");
		try {
			new GrammarManager(selectedGrammar + "." + grammarMainClassName,
					args);
			assertTrue(false);
		} catch (Exception e) {
			assertTrue(true);
		}

		args.put("file1", file1);

		// incorrect ou insupported encoding
		args.put("encoding", "bidon");
		try {
			new GrammarManager(selectedGrammar + "." + grammarMainClassName,
					args);
			assertTrue(false);
		} catch (Exception e) {
			assertTrue(true);
		}
	}

	/**
	 * <p>
	 * <b>test if the others process in grammar manager are well.</b>
	 * </p>
	 * 
	 * @since 0.6
	 */
	@Test
	public void testOthersProcess() {
		// initialize the grammar manager
		try {
			gm = new GrammarManager(selectedGrammar + "."
					+ grammarMainClassName, args);
			assertTrue(true);
		} catch (Exception e) {
			assertTrue(false);
		}

		// phonetic read process is executed correctly ?
		try {
			gm.toPhoneticRead(transliterationList, false);
			assertTrue(true);
		} catch (Exception e) {
			assertTrue(false);
		}

		args.put("encoding", "UTF-8");

		// main entry method to manage transliteration is correct ?
		args.put("methodNameToManageTransliteration", "bidon");

		try {
			gm.toTransliteration(signList, 0);
			assertTrue(false);
		} catch (Exception e) {
			assertTrue(true);
		}

		args.put("methodNameToManageTransliteration",
				methodNameToManageTransliteration);

		// main entry method to manage hieroglyphs is correct ?
		args.put("methodNameToManageHieroglyphs", "bidon");

		try {
			gm.toHieroglyphs(transliterationList);
			assertTrue(false);
		} catch (Exception e) {
			assertTrue(true);
		}

		args
				.put("methodNameToManageHieroglyphs",
						methodNameToManageHieroglyphs);

		// main entry method to phonetic read is correct ?
		args.put("methodNameToPhoneticRead", "bidon");

		try {
			gm.toPhoneticRead(transliterationList, false);
			assertTrue(false);
		} catch (Exception e) {
			assertTrue(true);
		}

		args.put("methodNameToPhoneticRead", methodNameToPhoneticRead);
	}

	/**
	 * <p>
	 * <b>test if the returned values are correct.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	@Test
	public void testValues() {
		// initialize the grammar manager
		try {
			gm = new GrammarManager(selectedGrammar + "."
					+ grammarMainClassName, args);
			assertTrue(true);
		} catch (Exception e1) {
			assertTrue(false);
		}

		// list of signs = null
		try {
			assertEquals(gm.toTransliteration(null, 0), "");
		} catch (Exception e) {
			assertTrue(false);
		}

		// list of transliteration = null
		try {
			assertEquals(gm.toHieroglyphs(null), "");
		} catch (Exception e) {
			assertTrue(false);
		}

		// list of transliteration = null
		try {
			assertEquals(gm.toPhoneticRead(null, false), "");
		} catch (Exception e) {
			assertTrue(false);
		}

		assertEquals(gm.toGrammaticalSequence(null), "");
	}
}
