/*
 * This file is a part of KEMET project (Library).
 * 
 * Copyright (C) 2008 MAUPIN Fabrice
 *
 * This library is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; 
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library; 
 * if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
package org.kemet.tests.composite;

import org.apache.log4j.Logger;
import org.junit.Test;
import org.kemet.impl.grammar.exceptions.KemetAPIException;
import org.kemet.impl.grammar.integration.HieroglyphManager;
import org.kemet.impl.grammar.integration.TransliterationManager;
import org.kemet.tests.TestRoot;

/**
 * 
 * 
 * @author fabricemaupin
 * 
 * <p>
 * <b>Tests for sequence multi - parts and broken.</b>
 * </p>
 * 
 * @since 0.2.3
 * 
 */
public class TestPartialSequence extends TestRoot {
	static Logger log = Logger.getLogger("org.kemet.tests");

	/**
	 * <p>
	 * <b>set the parameters before execute the tests.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Override
	public void init() {
		// nothing
	}

	/**
	 * <p>
	 * <b>partial sequence for transliteration (to hieroglyphs).</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test1() {
		// initialize the data tests
		sequence = "j?wn3";
		result = new String[] { "M17", "[G43;Z7]", "N35", "G1" };

		transliteration = new TransliterationManager(sequence, gm, phInfo,
				sortedPhInfo, TO_HIEROGLYPHS);

		try {
			String[] res = transliteration.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (Exception e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>partial sequence for transliteration (to type).</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test1b() {
		// initialize the data tests
		sequence = "j?wn3";
		result = new String[] {
				org.kemet.message.Messages.getString("INDICATOR_PPA"),
				org.kemet.message.Messages.getString("UNILITERAL"),
				org.kemet.message.Messages.getString("UNILITERAL") };

		transliteration = new TransliterationManager(sequence, gm, phInfo,
				sortedPhInfo, TO_TYPE);

		try {
			String[] res = transliteration.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (Exception e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>partial sequence for transliteration (to transliteration).</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test1c() {
		// initialize the data tests
		sequence = "j?wn3";
		result = new String[] { "jw", "n", "3" };

		transliteration = new TransliterationManager(sequence, gm, phInfo,
				sortedPhInfo, TO_TRANSLITERATION);

		try {
			String[] res = transliteration.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (Exception e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>partial sequence from hieroglyphs to transliteration.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test2() {
		// initialize the data tests
		sequence = "S29//Y5////S3Y1//Y2";
		result = new String[] { "s", "mn", "n" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_TRANSLITERATION);

		String[] res;
		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>partial sequence from hieroglyphs to transliteration part 2.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test3() {
		// initialize the data tests
		sequence = "S99//Y5////S3Y1//Y2";
		result = new String[] { "?", "mn", "n" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_TRANSLITERATION);

		String[] res;
		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			e.printStackTrace();
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>partial sequence from hieroglyphs to type.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test3b() {
		// initialize the data tests
		sequence = "S99//Y5////S3Y1//Y2";
		result = new String[] { "?",
				org.kemet.message.Messages.getString("BILITERAL"),
				org.kemet.message.Messages.getString("PC"),
				org.kemet.message.Messages.getString("IDEOGRAM"),
				org.kemet.message.Messages.getString("IDEOGRAM") };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo, TO_TYPE);

		String[] res;
		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			e.printStackTrace();
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>partial sequence from hieroglyphs to phonetic.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test3c() {
		// initialize the data tests
		sequence = "S99//Y5////S3Y1//Y2";
		result = new String[] { "ménèn" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);

		String[] res;
		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			e.printStackTrace();
			assertTrue(false);
		}
	}
}
